/* automatically generated from xfpm-settings.ui */
#ifdef __SUNPRO_C
#pragma align 4 (xfpm_settings_ui)
#endif
#ifdef __GNUC__
static const char xfpm_settings_ui[] __attribute__ ((__aligned__ (4))) =
#else
static const char xfpm_settings_ui[] =
#endif
{
  "<?xml version=\"1.0\" encoding=\"UTF-8\"?><interface><requires lib=\"gt"
  "k+\" version=\"3.20\"/><requires lib=\"libxfce4ui-2\" version=\"4.12\"/"
  "><object class=\"GtkAdjustment\" id=\"brightness-inactivity-on-ac-adjus"
  "tment\"><property name=\"lower\">0</property><property name=\"upper\">6"
  "0</property><property name=\"value\">0</property><property name=\"step_"
  "increment\">1</property><property name=\"page_increment\">6</property><"
  "/object><object class=\"GtkAdjustment\" id=\"brightness-inactivity-on-b"
  "attery-adjustment\"><property name=\"lower\">0</property><property name"
  "=\"upper\">60</property><property name=\"value\">30</property><property"
  " name=\"step_increment\">1</property><property name=\"page_increment\">"
  "6</property></object><object class=\"GtkAdjustment\" id=\"brightness-le"
  "vel-on-ac-adjustment\"><property name=\"lower\">1</property><property n"
  "ame=\"upper\">100</property><property name=\"value\">80</property><prop"
  "erty name=\"step_increment\">1</property><property name=\"page_incremen"
  "t\">10</property></object><object class=\"GtkAdjustment\" id=\"brightne"
  "ss-level-on-battery-adjustment\"><property name=\"lower\">1</property><"
  "property name=\"upper\">100</property><property name=\"value\">20</prop"
  "erty><property name=\"step_increment\">1</property><property name=\"pag"
  "e_increment\">10</property></object><object class=\"GtkAdjustment\" id="
  "\"brightness-step-count-spin-adjustment\"><property name=\"lower\">2</p"
  "roperty><property name=\"upper\">100</property><property name=\"value\""
  ">10</property><property name=\"step_increment\">5</property></object><o"
  "bject class=\"GtkAdjustment\" id=\"critical-power-level-spin-adjustment"
  "\"><property name=\"lower\">1</property><property name=\"upper\">70</pr"
  "operty><property name=\"value\">10</property><property name=\"step_incr"
  "ement\">1</property><property name=\"page_increment\">10</property></ob"
  "ject><object class=\"GtkAdjustment\" id=\"dpms-off-on-ac-adjustment\"><"
  "property name=\"upper\">60</property><property name=\"value\">15</prope"
  "rty><property name=\"step_increment\">1</property><property name=\"page"
  "_increment\">5</property></object><object class=\"GtkAdjustment\" id=\""
  "dpms-off-on-battery-adjustment\"><property name=\"upper\">60</property>"
  "<property name=\"value\">10</property><property name=\"step_increment\""
  ">1</property><property name=\"page_increment\">5</property></object><ob"
  "ject class=\"GtkAdjustment\" id=\"dpms-sleep-on-ac-adjustment\"><proper"
  "ty name=\"upper\">60</property><property name=\"value\">10</property><p"
  "roperty name=\"step_increment\">1</property><property name=\"page_incre"
  "ment\">5</property></object><object class=\"GtkAdjustment\" id=\"dpms-s"
  "leep-on-battery-adjustment\"><property name=\"upper\">60</property><pro"
  "perty name=\"value\">5</property><property name=\"step_increment\">1</p"
  "roperty><property name=\"page_increment\">5</property></object><object "
  "class=\"GtkImage\" id=\"image1\"><property name=\"visible\">True</prope"
  "rty><property name=\"can_focus\">False</property><property name=\"icon_"
  "name\">help-browser</property></object><object class=\"GtkImage\" id=\""
  "image2\"><property name=\"visible\">True</property><property name=\"can"
  "_focus\">False</property><property name=\"icon_name\">go-jump</property"
  "></object><object class=\"GtkImage\" id=\"image3\"><property name=\"vis"
  "ible\">True</property><property name=\"can_focus\">False</property><pro"
  "perty name=\"icon_name\">window-close-symbolic</property></object><obje"
  "ct class=\"GtkImage\" id=\"image4\"><property name=\"visible\">True</pr"
  "operty><property name=\"can_focus\">False</property><property name=\"ic"
  "on_name\">dialog-warning</property></object><object class=\"GtkListStor"
  "e\" id=\"liststore1\"><columns><column type=\"gint\"/><column type=\"gc"
  "hararray\"/></columns><data><row><col id=\"0\">0</col><col id=\"1\" tra"
  "nslatable=\"yes\">Never</col></row><row><col id=\"0\">1</col><col id=\""
  "1\" translatable=\"yes\">When the screensaver is activated</col></row><"
  "row><col id=\"0\">2</col><col id=\"1\" translatable=\"yes\">When the sc"
  "reensaver is deactivated</col></row></data></object><object class=\"Gtk"
  "ListStore\" id=\"model1\"><columns><column type=\"gchararray\"/></colum"
  "ns><data><row><col id=\"0\" translatable=\"yes\">Nothing</col></row></d"
  "ata></object><object class=\"GtkListStore\" id=\"model10\"><columns><co"
  "lumn type=\"gchararray\"/></columns><data><row><col id=\"0\" translatab"
  "le=\"yes\">Nothing</col></row></data></object><object class=\"GtkListSt"
  "ore\" id=\"model11\"><columns><column type=\"gchararray\"/></columns><d"
  "ata><row><col id=\"0\" translatable=\"yes\">Nothing</col></row></data><"
  "/object><object class=\"GtkListStore\" id=\"model3\"><columns><column t"
  "ype=\"gchararray\"/></columns><data><row><col id=\"0\" translatable=\"y"
  "es\">Nothing</col></row></data></object><object class=\"GtkListStore\" "
  "id=\"model4\"><columns><column type=\"gchararray\"/></columns><data><ro"
  "w><col id=\"0\" translatable=\"yes\">Nothing</col></row></data></object"
  "><object class=\"GtkListStore\" id=\"model5\"><columns><column type=\"g"
  "chararray\"/></columns><data><row><col id=\"0\" translatable=\"yes\">No"
  "thing</col></row></data></object><object class=\"GtkListStore\" id=\"mo"
  "del6\"><columns><column type=\"gchararray\"/></columns><data><row><col "
  "id=\"0\" translatable=\"yes\">Nothing</col></row></data></object><objec"
  "t class=\"GtkListStore\" id=\"model7\"><columns><column type=\"gchararr"
  "ay\"/></columns><data><row><col id=\"0\" translatable=\"yes\">Nothing</"
  "col></row></data></object><object class=\"GtkListStore\" id=\"model8\">"
  "<columns><column type=\"gchararray\"/></columns><data><row><col id=\"0\""
  " translatable=\"yes\">Nothing</col></row></data></object><object class="
  "\"GtkListStore\" id=\"model9\"><columns><column type=\"gchararray\"/></"
  "columns><data><row><col id=\"0\" translatable=\"yes\">Nothing</col></ro"
  "w></data></object><object class=\"GtkAdjustment\" id=\"system-sleep-ina"
  "ctivity-on-ac-adjustment\"><property name=\"lower\">0</property><proper"
  "ty name=\"upper\">60</property><property name=\"value\">0</property><pr"
  "operty name=\"step_increment\">1</property><property name=\"page_increm"
  "ent\">10</property></object><object class=\"GtkAdjustment\" id=\"system"
  "-sleep-inactivity-on-battery-adjustment\"><property name=\"lower\">0</p"
  "roperty><property name=\"upper\">60</property><property name=\"value\">"
  "0</property><property name=\"step_increment\">1</property><property nam"
  "e=\"page_increment\">10</property></object><object class=\"GtkPopover\""
  " id=\"critical-warning-popover\"><property name=\"can-focus\">False</pr"
  "operty><property name=\"position\">bottom</property><property name=\"bo"
  "rder-width\">6</property><child><object class=\"GtkLabel\" id=\"critica"
  "l-warning-label\"><property name=\"visible\">True</property><property n"
  "ame=\"can_focus\">False</property><property name=\"xalign\">0</property"
  "><property name=\"wrap\">True</property><property name=\"max-width-char"
  "s\">50</property></object></child></object><object class=\"XfceTitledDi"
  "alog\" id=\"xfpm-settings-dialog\"><property name=\"can_focus\">False</"
  "property><property name=\"title\" translatable=\"yes\">Power Manager</p"
  "roperty><property name=\"window_position\">center-on-parent</property><"
  "property name=\"icon_name\">org.xfce.powermanager</property><property n"
  "ame=\"type_hint\">dialog</property><child internal-child=\"vbox\"><obje"
  "ct class=\"GtkBox\" id=\"dialog-vbox\"><property name=\"visible\">True<"
  "/property><property name=\"can_focus\">False</property><property name=\""
  "orientation\">vertical</property><child internal-child=\"action_area\">"
  "<object class=\"GtkButtonBox\" id=\"dialog-action_area\"><property name"
  "=\"visible\">True</property><property name=\"can_focus\">False</propert"
  "y><child><object class=\"GtkButton\" id=\"help-button\"><property name="
  "\"label\" translatable=\"yes\">_Help</property><property name=\"visible"
  "\">True</property><property name=\"can_focus\">True</property><property"
  " name=\"receives_default\">True</property><property name=\"image\">imag"
  "e1</property><property name=\"use_underline\">True</property></object><"
  "packing><property name=\"expand\">False</property><property name=\"fill"
  "\">False</property><property name=\"position\">0</property><property na"
  "me=\"secondary\">True</property></packing></child><child><object class="
  "\"GtkButton\" id=\"screensaver-button\"><property name=\"label\" transl"
  "atable=\"yes\">_Screensaver Management</property><property name=\"visib"
  "le\">False</property><property name=\"can_focus\">True</property><prope"
  "rty name=\"receives_default\">True</property><property name=\"image\">i"
  "mage2</property><property name=\"use_underline\">True</property></objec"
  "t><packing><property name=\"expand\">False</property><property name=\"f"
  "ill\">False</property><property name=\"position\">1</property><property"
  " name=\"secondary\">True</property></packing></child><child><object cla"
  "ss=\"GtkButton\" id=\"close-button\"><property name=\"label\" translata"
  "ble=\"yes\">_Close</property><property name=\"visible\">True</property>"
  "<property name=\"can_focus\">True</property><property name=\"receives_d"
  "efault\">True</property><property name=\"image\">image3</property><prop"
  "erty name=\"use_underline\">True</property></object><packing><property "
  "name=\"expand\">False</property><property name=\"fill\">False</property"
  "><property name=\"position\">2</property></packing></child></object><pa"
  "cking><property name=\"expand\">False</property><property name=\"fill\""
  ">True</property><property name=\"position\">0</property></packing></chi"
  "ld><child><object class=\"GtkBox\" id=\"plug-child\"><property name=\"v"
  "isible\">True</property><property name=\"can_focus\">False</property><p"
  "roperty name=\"border_width\">6</property><property name=\"orientation\""
  ">vertical</property><child><object class=\"GtkNotebook\" id=\"main-note"
  "book\"><property name=\"visible\">True</property><property name=\"can_f"
  "ocus\">True</property><child><object class=\"GtkBox\" id=\"general-tab\""
  "><property name=\"visible\">True</property><property name=\"can_focus\""
  ">False</property><property name=\"border_width\">12</property><property"
  " name=\"orientation\">vertical</property><property name=\"spacing\">6</"
  "property><child><object class=\"GtkFrame\" id=\"buttons-frame\"><proper"
  "ty name=\"visible\">True</property><property name=\"can_focus\">False</"
  "property><property name=\"label_xalign\">0</property><property name=\"s"
  "hadow_type\">none</property><child><object class=\"GtkBox\" id=\"vbox2\""
  "><property name=\"visible\">True</property><property name=\"can_focus\""
  ">False</property><property name=\"margin_start\">18</property><property"
  " name=\"margin_top\">6</property><property name=\"margin_bottom\">18</p"
  "roperty><property name=\"orientation\">vertical</property><property nam"
  "e=\"spacing\">5</property><child><object class=\"GtkGrid\" id=\"table1\""
  "><property name=\"visible\">True</property><property name=\"can_focus\""
  ">False</property><property name=\"row_spacing\">6</property><property n"
  "ame=\"column_spacing\">6</property><child><object class=\"GtkLabel\" id"
  "=\"button-power-label\"><property name=\"visible\">True</property><prop"
  "erty name=\"can_focus\">False</property><property name=\"label\" transl"
  "atable=\"yes\">When power button is pressed:</property><property name=\""
  "xalign\">0</property></object><packing><property name=\"left_attach\">0"
  "</property><property name=\"top_attach\">0</property></packing></child>"
  "<child><object class=\"GtkLabel\" id=\"button-sleep-label\"><property n"
  "ame=\"visible\">True</property><property name=\"can_focus\">False</prop"
  "erty><property name=\"label\" translatable=\"yes\">When sleep button is"
  " pressed:</property><property name=\"xalign\">0</property></object><pac"
  "king><property name=\"left_attach\">0</property><property name=\"top_at"
  "tach\">1</property></packing></child><child><object class=\"GtkLabel\" "
  "id=\"button-hibernate-label\"><property name=\"visible\">True</property"
  "><property name=\"can_focus\">False</property><property name=\"label\" "
  "translatable=\"yes\">When hibernate button is pressed:</property><prope"
  "rty name=\"xalign\">0</property></object><packing><property name=\"left"
  "_attach\">0</property><property name=\"top_attach\">2</property></packi"
  "ng></child><child><object class=\"GtkLabel\" id=\"button-battery-label\""
  "><property name=\"visible\">True</property><property name=\"can_focus\""
  ">False</property><property name=\"label\" translatable=\"yes\">When bat"
  "tery button is pressed:</property><property name=\"xalign\">0</property"
  "></object><packing><property name=\"left_attach\">0</property><property"
  " name=\"top_attach\">3</property></packing></child><child><object class"
  "=\"GtkComboBox\" id=\"button-power-combo\"><property name=\"visible\">T"
  "rue</property><property name=\"can_focus\">False</property><property na"
  "me=\"hexpand\">True</property><child><object class=\"GtkCellRendererTex"
  "t\" id=\"renderer1\"/><attributes><attribute name=\"text\">0</attribute"
  "></attributes></child></object><packing><property name=\"left_attach\">"
  "1</property><property name=\"top_attach\">0</property></packing></child"
  "><child><object class=\"GtkComboBox\" id=\"button-sleep-combo\"><proper"
  "ty name=\"visible\">True</property><property name=\"can_focus\">False</"
  "property><property name=\"hexpand\">True</property><child><object class"
  "=\"GtkCellRendererText\" id=\"renderer4\"/><attributes><attribute name="
  "\"text\">0</attribute></attributes></child></object><packing><property "
  "name=\"left_attach\">1</property><property name=\"top_attach\">1</prope"
  "rty></packing></child><child><object class=\"GtkComboBox\" id=\"button-"
  "hibernate-combo\"><property name=\"visible\">True</property><property n"
  "ame=\"can_focus\">False</property><property name=\"hexpand\">True</prop"
  "erty><child><object class=\"GtkCellRendererText\" id=\"renderer3\"/><at"
  "tributes><attribute name=\"text\">0</attribute></attributes></child></o"
  "bject><packing><property name=\"left_attach\">1</property><property nam"
  "e=\"top_attach\">2</property></packing></child><child><object class=\"G"
  "tkComboBox\" id=\"button-battery-combo\"><property name=\"visible\">Tru"
  "e</property><property name=\"can_focus\">False</property><property name"
  "=\"hexpand\">True</property><child><object class=\"GtkCellRendererText\""
  " id=\"renderer5\"/><attributes><attribute name=\"text\">0</attribute></"
  "attributes></child></object><packing><property name=\"left_attach\">1</"
  "property><property name=\"top_attach\">3</property></packing></child><c"
  "hild><object class=\"GtkSwitch\" id=\"handle-brightness-keys\"><propert"
  "y name=\"visible\">True</property><property name=\"can_focus\">True</pr"
  "operty><property name=\"halign\">end</property></object><packing><prope"
  "rty name=\"left_attach\">1</property><property name=\"top_attach\">4</p"
  "roperty></packing></child><child><object class=\"GtkBox\" id=\"hbox4\">"
  "<property name=\"visible\">True</property><property name=\"can_focus\">"
  "False</property><property name=\"spacing\">6</property><child><object c"
  "lass=\"GtkSpinButton\" id=\"brightness-step-count-spin\"><property name"
  "=\"visible\">True</property><property name=\"can_focus\">True</property"
  "><property name=\"hexpand\">False</property><property name=\"invisible_"
  "char\">\342\227\217</property><property name=\"primary_icon_activatable"
  "\">False</property><property name=\"secondary_icon_activatable\">False<"
  "/property><property name=\"adjustment\">brightness-step-count-spin-adju"
  "stment</property></object><packing><property name=\"expand\">False</pro"
  "perty><property name=\"fill\">False</property></packing></child><child>"
  "<object class=\"GtkCheckButton\" id=\"brightness-exponential\"><propert"
  "y name=\"label\" translatable=\"yes\">Exponential</property><property n"
  "ame=\"visible\">True</property><property name=\"can_focus\">True</prope"
  "rty><property name=\"receives_default\">False</property><property name="
  "\"draw_indicator\">True</property></object><packing><property name=\"ex"
  "pand\">False</property><property name=\"fill\">True</property></packing"
  "></child></object><packing><property name=\"left_attach\">1</property><"
  "property name=\"top_attach\">5</property></packing></child><child><obje"
  "ct class=\"GtkLabel\" id=\"brightness-step-count-label\"><property name"
  "=\"visible\">True</property><property name=\"can_focus\">False</propert"
  "y><property name=\"xalign\">0</property><property name=\"label\" transl"
  "atable=\"yes\">Brightness step count:</property></object><packing><prop"
  "erty name=\"left_attach\">0</property><property name=\"top_attach\">5</"
  "property></packing></child><child><object class=\"GtkLabel\" id=\"handl"
  "e-brightness-keys-label\"><property name=\"visible\">True</property><pr"
  "operty name=\"can_focus\">False</property><property name=\"label\" tran"
  "slatable=\"yes\">Handle display brightness _keys</property><property na"
  "me=\"use_underline\">True</property><property name=\"ellipsize\">end</p"
  "roperty><property name=\"xalign\">0</property></object><packing><proper"
  "ty name=\"left_attach\">0</property><property name=\"top_attach\">4</pr"
  "operty></packing></child></object><packing><property name=\"expand\">Tr"
  "ue</property><property name=\"fill\">True</property><property name=\"po"
  "sition\">0</property></packing></child></object></child><child type=\"l"
  "abel\"><object class=\"GtkLabel\" id=\"label1\"><property name=\"visibl"
  "e\">True</property><property name=\"can_focus\">False</property><proper"
  "ty name=\"label\" translatable=\"yes\">&lt;b&gt;Buttons&lt;/b&gt;</prop"
  "erty><property name=\"use_markup\">True</property></object></child></ob"
  "ject><packing><property name=\"expand\">False</property><property name="
  "\"fill\">True</property><property name=\"position\">0</property></packi"
  "ng></child><child><object class=\"GtkFrame\" id=\"appearance-frame\"><p"
  "roperty name=\"visible\">True</property><property name=\"can_focus\">Fa"
  "lse</property><property name=\"label_xalign\">0</property><property nam"
  "e=\"shadow_type\">none</property><child><object class=\"GtkBox\" id=\"v"
  "box10\"><property name=\"visible\">True</property><property name=\"can_"
  "focus\">False</property><property name=\"margin_start\">18</property><p"
  "roperty name=\"margin_top\">6</property><property name=\"margin_bottom\""
  ">18</property><property name=\"orientation\">vertical</property><proper"
  "ty name=\"spacing\">6</property><child><object class=\"GtkBox\" id=\"hb"
  "ox20\"><property name=\"visible\">True</property><property name=\"can_f"
  "ocus\">False</property><child><object class=\"GtkLabel\" id=\"show-noti"
  "fications-label\"><property name=\"visible\">True</property><property n"
  "ame=\"can_focus\">False</property><property name=\"label\" translatable"
  "=\"yes\">Status notifications</property><property name=\"use_underline\""
  ">True</property><property name=\"ellipsize\">end</property><property na"
  "me=\"xalign\">0</property></object><packing><property name=\"expand\">T"
  "rue</property><property name=\"fill\">True</property><property name=\"p"
  "osition\">0</property></packing></child><child><object class=\"GtkSwitc"
  "h\" id=\"show-notifications\"><property name=\"visible\">True</property"
  "><property name=\"can_focus\">True</property><property name=\"halign\">"
  "end</property></object><packing><property name=\"expand\">False</proper"
  "ty><property name=\"fill\">True</property><property name=\"position\">1"
  "</property></packing></child></object><packing><property name=\"expand\""
  ">True</property><property name=\"fill\">True</property><property name=\""
  "position\">1</property></packing></child><child><object class=\"GtkBox\""
  " id=\"hbox21\"><property name=\"visible\">True</property><property name"
  "=\"can_focus\">False</property><child><object class=\"GtkLabel\" id=\"s"
  "how-systray-label\"><property name=\"visible\">True</property><property"
  " name=\"can_focus\">False</property><property name=\"label\" translatab"
  "le=\"yes\">System tray icon</property><property name=\"use_underline\">"
  "True</property><property name=\"ellipsize\">end</property><property nam"
  "e=\"xalign\">0</property></object><packing><property name=\"expand\">Tr"
  "ue</property><property name=\"fill\">True</property><property name=\"po"
  "sition\">0</property></packing></child><child><object class=\"GtkSwitch"
  "\" id=\"show-systray\"><property name=\"visible\">True</property><prope"
  "rty name=\"can_focus\">True</property><property name=\"halign\">end</pr"
  "operty></object><packing><property name=\"expand\">False</property><pro"
  "perty name=\"fill\">True</property><property name=\"position\">1</prope"
  "rty></packing></child></object><packing><property name=\"expand\">True<"
  "/property><property name=\"fill\">True</property><property name=\"posit"
  "ion\">2</property></packing></child></object></child><child type=\"labe"
  "l\"><object class=\"GtkLabel\" id=\"label2\"><property name=\"visible\""
  ">True</property><property name=\"can_focus\">False</property><property "
  "name=\"label\" translatable=\"yes\">&lt;b&gt;Appearance&lt;/b&gt;</prop"
  "erty><property name=\"use_markup\">True</property></object></child></ob"
  "ject><packing><property name=\"expand\">False</property><property name="
  "\"fill\">True</property><property name=\"position\">2</property></packi"
  "ng></child></object><packing><property name=\"position\">1</property></"
  "packing></child><child type=\"tab\"><object class=\"GtkLabel\" id=\"gen"
  "eral\"><property name=\"visible\">True</property><property name=\"can_f"
  "ocus\">False</property><property name=\"label\" translatable=\"yes\">Ge"
  "neral</property></object><packing><property name=\"position\">1</proper"
  "ty><property name=\"tab_fill\">False</property></packing></child><child"
  "><object class=\"GtkBox\" id=\"system-tab\"><property name=\"visible\">"
  "True</property><property name=\"can_focus\">False</property><property n"
  "ame=\"border_width\">12</property><property name=\"orientation\">vertic"
  "al</property><property name=\"spacing\">6</property><child><object clas"
  "s=\"GtkStackSwitcher\" id=\"system-stack-switcher\"><property name=\"vi"
  "sible\">True</property><property name=\"can_focus\">False</property><pr"
  "operty name=\"halign\">center</property><property name=\"valign\">cente"
  "r</property><property name=\"margin_bottom\">6</property><property name"
  "=\"stack\">system-stack</property></object><packing><property name=\"ex"
  "pand\">False</property><property name=\"fill\">True</property><property"
  " name=\"position\">0</property></packing></child><child><object class=\""
  "GtkStack\" id=\"system-stack\"><property name=\"visible\">True</propert"
  "y><property name=\"can_focus\">False</property><property name=\"transit"
  "ion_type\">slide-left-right</property><child><object class=\"GtkGrid\">"
  "<property name=\"visible\">True</property><property name=\"can_focus\">"
  "False</property><property name=\"row_spacing\">6</property><property na"
  "me=\"column_spacing\">12</property><child><object class=\"GtkLabel\" id"
  "=\"system-sleep-inactivity-label\"><property name=\"visible\">True</pro"
  "perty><property name=\"can_focus\">False</property><property name=\"mar"
  "gin_left\">18</property><property name=\"label\" translatable=\"yes\">W"
  "hen inactive for</property><property name=\"xalign\">0</property></obje"
  "ct><packing><property name=\"left_attach\">0</property><property name=\""
  "top_attach\">2</property></packing></child><child><object class=\"GtkBo"
  "x\"><property name=\"visible\">True</property><property name=\"can_focu"
  "s\">False</property><property name=\"orientation\">vertical</property><"
  "child><object class=\"GtkScale\" id=\"system-sleep-inactivity-on-batter"
  "y\"><property name=\"visible\">True</property><property name=\"can_focu"
  "s\">True</property><property name=\"adjustment\">system-sleep-inactivit"
  "y-on-battery-adjustment</property><property name=\"round_digits\">0</pr"
  "operty><property name=\"digits\">0</property><property name=\"draw_valu"
  "e\">False</property><style><class name=\"xfce4-scale-label\"/></style><"
  "/object><packing><property name=\"expand\">False</property><property na"
  "me=\"fill\">True</property><property name=\"position\">0</property></pa"
  "cking></child><child><object class=\"GtkLabel\" id=\"system-sleep-inact"
  "ivity-on-battery-label\"><property name=\"visible\">True</property><pro"
  "perty name=\"sensitive\">False</property><property name=\"can_focus\">F"
  "alse</property><property name=\"xalign\">0.5</property></object><packin"
  "g><property name=\"expand\">False</property><property name=\"fill\">Tru"
  "e</property><property name=\"position\">1</property></packing></child><"
  "/object><packing><property name=\"left_attach\">1</property><property n"
  "ame=\"top_attach\">2</property></packing></child><child><object class=\""
  "GtkComboBox\" id=\"system-sleep-mode-on-battery\"><property name=\"visi"
  "ble\">True</property><property name=\"can_focus\">False</property><prop"
  "erty name=\"hexpand\">True</property><child><object class=\"GtkCellRend"
  "ererText\" id=\"renderer8\"/><attributes><attribute name=\"text\">0</at"
  "tribute></attributes></child></object><packing><property name=\"left_at"
  "tach\">1</property><property name=\"top_attach\">1</property></packing>"
  "</child><child><object class=\"GtkLabel\" id=\"system-sleep-mode-label\""
  "><property name=\"visible\">True</property><property name=\"can_focus\""
  ">False</property><property name=\"margin_left\">18</property><property "
  "name=\"label\" translatable=\"yes\">System sleep mode:</property><prope"
  "rty name=\"xalign\">0</property></object><packing><property name=\"left"
  "_attach\">0</property><property name=\"top_attach\">1</property></packi"
  "ng></child><child><object class=\"GtkLabel\" id=\"label10\"><property n"
  "ame=\"visible\">True</property><property name=\"can_focus\">False</prop"
  "erty><property name=\"label\" translatable=\"yes\">&lt;b&gt;System powe"
  "r saving&lt;/b&gt;</property><property name=\"use_markup\">True</proper"
  "ty><property name=\"xalign\">0</property></object><packing><property na"
  "me=\"left_attach\">0</property><property name=\"top_attach\">0</propert"
  "y><property name=\"width\">2</property></packing></child><child><object"
  " class=\"GtkLabel\" id=\"lid-on-battery-header\"><property name=\"visib"
  "le\">True</property><property name=\"can_focus\">False</property><prope"
  "rty name=\"margin_top\">12</property><property name=\"label\" translata"
  "ble=\"yes\">&lt;b&gt;Laptop Lid&lt;/b&gt;</property><property name=\"us"
  "e_markup\">True</property><property name=\"xalign\">0</property></objec"
  "t><packing><property name=\"left_attach\">0</property><property name=\""
  "top_attach\">3</property><property name=\"width\">2</property></packing"
  "></child><child><object class=\"GtkLabel\" id=\"lid-action-label\"><pro"
  "perty name=\"visible\">True</property><property name=\"can_focus\">Fals"
  "e</property><property name=\"margin_left\">18</property><property name="
  "\"label\" translatable=\"yes\">When laptop lid is closed:</property><pr"
  "operty name=\"tooltip-text\" translatable=\"yes\">These actions only ta"
  "ke place if no external display is connected</property><property name=\""
  "xalign\">0</property></object><packing><property name=\"left_attach\">0"
  "</property><property name=\"top_attach\">4</property></packing></child>"
  "<child><object class=\"GtkComboBox\" id=\"lid-on-battery-combo\"><prope"
  "rty name=\"visible\">True</property><property name=\"can_focus\">False<"
  "/property><property name=\"hexpand\">True</property><property name=\"to"
  "oltip-text\" translatable=\"yes\">These actions only take place if no e"
  "xternal display is connected</property><child><object class=\"GtkCellRe"
  "ndererText\" id=\"renderer9\"/><attributes><attribute name=\"text\">0</"
  "attribute></attributes></child></object><packing><property name=\"left_"
  "attach\">1</property><property name=\"top_attach\">4</property></packin"
  "g></child><child><object class=\"GtkLabel\" id=\"power-profile-label-on"
  "-battery\"><property name=\"visible\">True</property><property name=\"c"
  "an_focus\">False</property><property name=\"label\" translatable=\"yes\""
  ">&lt;b&gt;Power profile&lt;/b&gt;</property>a\n                        "
  "        <property name=\"use_markup\">True</property><property name=\"x"
  "align\">0</property></object><packing><property name=\"left_attach\">0<"
  "/property><property name=\"top_attach\">5</property><property name=\"wi"
  "dth\">2</property></packing></child><child><object class=\"GtkComboBox\""
  " id=\"power-profile-on-battery\"><property name=\"visible\">True</prope"
  "rty><property name=\"can_focus\">False</property><property name=\"hexpa"
  "nd\">True</property><property name=\"id-column\">0</property><child><ob"
  "ject class=\"GtkCellRendererText\" id=\"renderer12\"/><attributes><attr"
  "ibute name=\"text\">0</attribute></attributes></child></object><packing"
  "><property name=\"left_attach\">0</property><property name=\"top_attach"
  "\">6</property><property name=\"width\">2</property></packing></child><"
  "/object><packing><property name=\"name\">page0</property><property name"
  "=\"title\" translatable=\"yes\">On battery</property></packing></child>"
  "<child><object class=\"GtkGrid\"><property name=\"visible\">True</prope"
  "rty><property name=\"can_focus\">False</property><property name=\"row_s"
  "pacing\">6</property><property name=\"column_spacing\">12</property><ch"
  "ild><object class=\"GtkLabel\" id=\"lid-action-label1\"><property name="
  "\"visible\">True</property><property name=\"can_focus\">False</property"
  "><property name=\"margin_left\">18</property><property name=\"label\" t"
  "ranslatable=\"yes\">When laptop lid is closed:</property><property name"
  "=\"tooltip-text\" translatable=\"yes\">These actions only take place if"
  " no external display is connected</property><property name=\"xalign\">0"
  "</property></object><packing><property name=\"left_attach\">0</property"
  "><property name=\"top_attach\">4</property></packing></child><child><ob"
  "ject class=\"GtkComboBox\" id=\"lid-on-ac-combo\"><property name=\"visi"
  "ble\">True</property><property name=\"can_focus\">False</property><prop"
  "erty name=\"hexpand\">True</property><property name=\"tooltip-text\" tr"
  "anslatable=\"yes\">These actions only take place if no external display"
  " is connected</property><child><object class=\"GtkCellRendererText\" id"
  "=\"renderer10\"/><attributes><attribute name=\"text\">0</attribute></at"
  "tributes></child></object><packing><property name=\"left_attach\">1</pr"
  "operty><property name=\"top_attach\">4</property></packing></child><chi"
  "ld><object class=\"GtkLabel\" id=\"lid-plugged-in-header\"><property na"
  "me=\"visible\">True</property><property name=\"can_focus\">False</prope"
  "rty><property name=\"margin_top\">12</property><property name=\"label\""
  " translatable=\"yes\">&lt;b&gt;Laptop Lid&lt;/b&gt;</property><property"
  " name=\"use_markup\">True</property><property name=\"xalign\">0</proper"
  "ty></object><packing><property name=\"left_attach\">0</property><proper"
  "ty name=\"top_attach\">3</property><property name=\"width\">2</property"
  "></packing></child><child><object class=\"GtkLabel\" id=\"system-sleep-"
  "inactivity-label1\"><property name=\"visible\">True</property><property"
  " name=\"can_focus\">False</property><property name=\"margin_left\">18</"
  "property><property name=\"label\" translatable=\"yes\">When inactive fo"
  "r</property><property name=\"xalign\">0</property></object><packing><pr"
  "operty name=\"left_attach\">0</property><property name=\"top_attach\">2"
  "</property></packing></child><child><object class=\"GtkBox\"><property "
  "name=\"visible\">True</property><property name=\"can_focus\">False</pro"
  "perty><property name=\"orientation\">vertical</property><child><object "
  "class=\"GtkScale\" id=\"system-sleep-inactivity-on-ac\"><property name="
  "\"visible\">True</property><property name=\"can_focus\">True</property>"
  "<property name=\"adjustment\">system-sleep-inactivity-on-ac-adjustment<"
  "/property><property name=\"round_digits\">0</property><property name=\""
  "digits\">0</property><property name=\"draw_value\">False</property><sty"
  "le><class name=\"xfce4-scale-label\"/></style></object><packing><proper"
  "ty name=\"expand\">False</property><property name=\"fill\">True</proper"
  "ty><property name=\"position\">0</property></packing></child><child><ob"
  "ject class=\"GtkLabel\" id=\"system-sleep-inactivity-on-ac-label\"><pro"
  "perty name=\"visible\">True</property><property name=\"sensitive\">Fals"
  "e</property><property name=\"can_focus\">False</property><property name"
  "=\"xalign\">0.5</property></object><packing><property name=\"expand\">T"
  "rue</property><property name=\"fill\">True</property><property name=\"p"
  "osition\">1</property></packing></child></object><packing><property nam"
  "e=\"left_attach\">1</property><property name=\"top_attach\">2</property"
  "></packing></child><child><object class=\"GtkComboBox\" id=\"system-sle"
  "ep-mode-on-ac\"><property name=\"visible\">True</property><property nam"
  "e=\"can_focus\">False</property><property name=\"hexpand\">True</proper"
  "ty><child><object class=\"GtkCellRendererText\" id=\"renderer2\"/><attr"
  "ibutes><attribute name=\"text\">0</attribute></attributes></child></obj"
  "ect><packing><property name=\"left_attach\">1</property><property name="
  "\"top_attach\">1</property></packing></child><child><object class=\"Gtk"
  "Label\" id=\"system-sleep-mode-label1\"><property name=\"visible\">True"
  "</property><property name=\"can_focus\">False</property><property name="
  "\"margin_left\">18</property><property name=\"label\" translatable=\"ye"
  "s\">System sleep mode:</property><property name=\"xalign\">0</property>"
  "</object><packing><property name=\"left_attach\">0</property><property "
  "name=\"top_attach\">1</property></packing></child><child><object class="
  "\"GtkLabel\" id=\"label8\"><property name=\"visible\">True</property><p"
  "roperty name=\"can_focus\">False</property><property name=\"label\" tra"
  "nslatable=\"yes\">&lt;b&gt;System power saving&lt;/b&gt;</property><pro"
  "perty name=\"use_markup\">True</property><property name=\"xalign\">0</p"
  "roperty></object><packing><property name=\"left_attach\">0</property><p"
  "roperty name=\"top_attach\">0</property><property name=\"width\">2</pro"
  "perty></packing></child><child><object class=\"GtkLabel\" id=\"power-pr"
  "ofile-label-on-ac\"><property name=\"visible\">True</property><property"
  " name=\"can_focus\">False</property><property name=\"label\" translatab"
  "le=\"yes\">&lt;b&gt;Power profile&lt;/b&gt;</property>a\n              "
  "                  <property name=\"use_markup\">True</property><propert"
  "y name=\"xalign\">0</property></object><packing><property name=\"left_a"
  "ttach\">0</property><property name=\"top_attach\">5</property><property"
  " name=\"width\">2</property></packing></child><child><object class=\"Gt"
  "kComboBox\" id=\"power-profile-on-ac\"><property name=\"visible\">True<"
  "/property><property name=\"can_focus\">False</property><property name=\""
  "hexpand\">True</property><property name=\"id-column\">0</property><chil"
  "d><object class=\"GtkCellRendererText\" id=\"renderer6\"/><attributes><"
  "attribute name=\"text\">0</attribute></attributes></child></object><pac"
  "king><property name=\"left_attach\">0</property><property name=\"top_at"
  "tach\">6</property><property name=\"width\">2</property></packing></chi"
  "ld></object><packing><property name=\"name\">page1</property><property "
  "name=\"title\" translatable=\"yes\">Plugged in</property><property name"
  "=\"position\">1</property></packing></child></object><packing><property"
  " name=\"expand\">False</property><property name=\"fill\">True</property"
  "><property name=\"position\">1</property></packing></child><child><obje"
  "ct class=\"GtkFrame\" id=\"critical-power-frame\"><property name=\"visi"
  "ble\">True</property><property name=\"can_focus\">False</property><prop"
  "erty name=\"margin_top\">12</property><property name=\"label_xalign\">0"
  "</property><property name=\"shadow_type\">none</property><child><object"
  " class=\"GtkBox\" id=\"vbox4\"><property name=\"visible\">True</propert"
  "y><property name=\"can_focus\">False</property><property name=\"margin_"
  "start\">18</property><property name=\"margin_top\">6</property><propert"
  "y name=\"margin_bottom\">12</property><property name=\"orientation\">ve"
  "rtical</property><property name=\"spacing\">3</property><child><object "
  "class=\"GtkBox\" id=\"hbox2\"><property name=\"visible\">True</property"
  "><property name=\"can_focus\">False</property><property name=\"spacing\""
  ">6</property><child><object class=\"GtkLabel\" id=\"critical-power-leve"
  "l-label\"><property name=\"visible\">True</property><property name=\"ca"
  "n_focus\">False</property><property name=\"label\" translatable=\"yes\""
  ">Critical battery power level:</property><property name=\"xalign\">0</p"
  "roperty></object><packing><property name=\"expand\">False</property><pr"
  "operty name=\"fill\">True</property><property name=\"position\">0</prop"
  "erty></packing></child><child><object class=\"GtkSpinButton\" id=\"crit"
  "ical-power-level-spin\"><property name=\"width_request\">100</property>"
  "<property name=\"visible\">True</property><property name=\"can_focus\">"
  "True</property><property name=\"invisible_char\">\342\227\217</property"
  "><property name=\"width_chars\">6</property><property name=\"primary_ic"
  "on_activatable\">False</property><property name=\"secondary_icon_activa"
  "table\">False</property><property name=\"adjustment\">critical-power-le"
  "vel-spin-adjustment</property></object><packing><property name=\"expand"
  "\">False</property><property name=\"fill\">True</property><property nam"
  "e=\"position\">1</property></packing></child><child><object class=\"Gtk"
  "Label\"><property name=\"visible\">True</property><property name=\"can_"
  "focus\">False</property><property name=\"label\" translatable=\"yes\">%"
  "</property></object><packing><property name=\"expand\">False</property>"
  "<property name=\"fill\">True</property><property name=\"position\">2</p"
  "roperty></packing></child><child><object class=\"GtkMenuButton\" id=\"c"
  "ritical-warning-button\"><property name=\"visible\">True</property><pro"
  "perty name=\"can-focus\">True</property><property name=\"image\">image4"
  "</property><property name=\"popover\">critical-warning-popover</propert"
  "y></object><packing><property name=\"expand\">False</property><property"
  " name=\"fill\">True</property><property name=\"position\">3</property><"
  "/packing></child></object><packing><property name=\"expand\">False</pro"
  "perty><property name=\"fill\">True</property><property name=\"position\""
  ">0</property></packing></child><child><object class=\"GtkBox\" id=\"hbo"
  "x3\"><property name=\"visible\">True</property><property name=\"can_foc"
  "us\">False</property><property name=\"spacing\">6</property><child><obj"
  "ect class=\"GtkLabel\" id=\"critical-power-action-label\"><property nam"
  "e=\"visible\">True</property><property name=\"can_focus\">False</proper"
  "ty><property name=\"label\" translatable=\"yes\">On critical battery po"
  "wer:</property><property name=\"xalign\">0</property></object><packing>"
  "<property name=\"expand\">False</property><property name=\"fill\">True<"
  "/property><property name=\"position\">0</property></packing></child><ch"
  "ild><object class=\"GtkComboBox\" id=\"critical-power-action-combo\"><p"
  "roperty name=\"visible\">True</property><property name=\"can_focus\">Fa"
  "lse</property><child><object class=\"GtkCellRendererText\" id=\"rendere"
  "r7\"/><attributes><attribute name=\"text\">0</attribute></attributes></"
  "child></object><packing><property name=\"expand\">True</property><prope"
  "rty name=\"fill\">True</property><property name=\"position\">1</propert"
  "y></packing></child></object><packing><property name=\"expand\">False</"
  "property><property name=\"fill\">True</property><property name=\"positi"
  "on\">1</property></packing></child></object></child><child type=\"label"
  "\"><object class=\"GtkLabel\" id=\"label9\"><property name=\"visible\">"
  "True</property><property name=\"can_focus\">False</property><property n"
  "ame=\"label\" translatable=\"yes\">&lt;b&gt;Critical power&lt;/b&gt;</p"
  "roperty><property name=\"use_markup\">True</property></object></child><"
  "/object><packing><property name=\"expand\">False</property><property na"
  "me=\"fill\">True</property><property name=\"position\">2</property></pa"
  "cking></child><child><object class=\"GtkFrame\" id=\"security-frame\"><"
  "property name=\"visible\">True</property><property name=\"can_focus\">F"
  "alse</property><property name=\"margin_top\">6</property><property name"
  "=\"label_xalign\">0</property><property name=\"shadow_type\">none</prop"
  "erty><child><object class=\"GtkBox\" id=\"vbox11\"><property name=\"vis"
  "ible\">True</property><property name=\"can_focus\">False</property><pro"
  "perty name=\"margin_start\">6</property><property name=\"margin_top\">6"
  "</property><property name=\"margin_bottom\">12</property><property name"
  "=\"orientation\">vertical</property><property name=\"spacing\">6</prope"
  "rty><child><object class=\"GtkCheckButton\" id=\"lock-screen\"><propert"
  "y name=\"label\" translatable=\"yes\">Lock screen when system is going "
  "to sleep</property><property name=\"visible\">True</property><property "
  "name=\"can_focus\">True</property><property name=\"receives_default\">F"
  "alse</property><property name=\"margin_left\">6</property><property nam"
  "e=\"draw_indicator\">True</property></object><packing><property name=\""
  "expand\">False</property><property name=\"fill\">True</property><proper"
  "ty name=\"position\">0</property></packing></child></object></child><ch"
  "ild type=\"label\"><object class=\"GtkLabel\" id=\"label5\"><property n"
  "ame=\"visible\">True</property><property name=\"can_focus\">False</prop"
  "erty><property name=\"label\" translatable=\"yes\">&lt;b&gt;Security&lt"
  ";/b&gt;</property><property name=\"use_markup\">True</property></object"
  "></child></object><packing><property name=\"expand\">False</property><p"
  "roperty name=\"fill\">True</property><property name=\"position\">3</pro"
  "perty></packing></child></object><packing><property name=\"position\">1"
  "</property></packing></child><child type=\"tab\"><object class=\"GtkLab"
  "el\" id=\"system\"><property name=\"visible\">True</property><property "
  "name=\"can_focus\">False</property><property name=\"label\" translatabl"
  "e=\"yes\">System</property></object><packing><property name=\"position\""
  ">1</property><property name=\"tab_fill\">False</property></packing></ch"
  "ild><child><object class=\"GtkBox\" id=\"display-tab\"><property name=\""
  "visible\">True</property><property name=\"can_focus\">False</property><"
  "property name=\"valign\">start</property><property name=\"vexpand\">Tru"
  "e</property><property name=\"border_width\">12</property><property name"
  "=\"orientation\">vertical</property><property name=\"spacing\">6</prope"
  "rty><child><object class=\"GtkStackSwitcher\" id=\"display-stack-switch"
  "er\"><property name=\"visible\">True</property><property name=\"can_foc"
  "us\">False</property><property name=\"halign\">center</property><proper"
  "ty name=\"valign\">center</property><property name=\"margin_bottom\">6<"
  "/property><property name=\"stack\">display-stack</property></object><pa"
  "cking><property name=\"expand\">True</property><property name=\"fill\">"
  "True</property><property name=\"position\">0</property></packing></chil"
  "d><child><object class=\"GtkBox\" id=\"dpms-frame\"><property name=\"vi"
  "sible\">True</property><property name=\"can_focus\">False</property><ch"
  "ild><object class=\"GtkLabel\" id=\"dpms-label\"><property name=\"visib"
  "le\">True</property><property name=\"can_focus\">False</property><prope"
  "rty name=\"label\" translatable=\"yes\">&lt;b&gt;Display power manageme"
  "nt&lt;/b&gt;</property><property name=\"use_markup\">True</property></o"
  "bject><packing><property name=\"expand\">False</property><property name"
  "=\"fill\">True</property><property name=\"position\">0</property></pack"
  "ing></child><child><object class=\"GtkSwitch\" id=\"handle-dpms\"><prop"
  "erty name=\"visible\">True</property><property name=\"can_focus\">True<"
  "/property><property name=\"tooltip_text\" translatable=\"yes\">Let the "
  "power manager handle display power management (DPMS) instead of the dis"
  "play server</property></object><packing><property name=\"expand\">False"
  "</property><property name=\"fill\">True</property><property name=\"pack"
  "_type\">end</property><property name=\"position\">1</property></packing"
  "></child></object><packing><property name=\"expand\">False</property><p"
  "roperty name=\"fill\">True</property><property name=\"position\">1</pro"
  "perty></packing></child><child><object class=\"GtkStack\" id=\"display-"
  "stack\"><property name=\"visible\">True</property><property name=\"can_"
  "focus\">False</property><property name=\"transition_type\">slide-left-r"
  "ight</property><child><object class=\"GtkGrid\" id=\"display-battery-gr"
  "id\"><property name=\"visible\">True</property><property name=\"can_foc"
  "us\">False</property><property name=\"row_spacing\">6</property><proper"
  "ty name=\"column_spacing\">12</property><child><object class=\"GtkBox\""
  " id=\"dpms-sleep-box\"><property name=\"visible\">True</property><prope"
  "rty name=\"can_focus\">False</property><property name=\"orientation\">v"
  "ertical</property><child><object class=\"GtkScale\" id=\"dpms-sleep-on-"
  "battery\"><property name=\"visible\">True</property><property name=\"ca"
  "n_focus\">True</property><property name=\"hexpand\">True</property><pro"
  "perty name=\"adjustment\">dpms-sleep-on-battery-adjustment</property><p"
  "roperty name=\"round_digits\">0</property><property name=\"digits\">0</"
  "property><property name=\"draw_value\">False</property><style><class na"
  "me=\"xfce4-scale-label\"/></style></object><packing><property name=\"ex"
  "pand\">False</property><property name=\"fill\">True</property><property"
  " name=\"position\">0</property></packing></child><child><object class=\""
  "GtkLabel\" id=\"dpms-sleep-on-battery-label\"><property name=\"visible\""
  ">True</property><property name=\"sensitive\">False</property><property "
  "name=\"can_focus\">False</property><property name=\"xalign\">0.5</prope"
  "rty></object><packing><property name=\"expand\">False</property><proper"
  "ty name=\"fill\">True</property><property name=\"position\">1</property"
  "></packing></child></object><packing><property name=\"left_attach\">1</"
  "property><property name=\"top_attach\">1</property></packing></child><c"
  "hild><object class=\"GtkLabel\" id=\"dpms-sleep-label\"><property name="
  "\"visible\">True</property><property name=\"can_focus\">False</property"
  "><property name=\"margin_left\">18</property><property name=\"label\" t"
  "ranslatable=\"yes\">Put to sleep after</property><property name=\"xalig"
  "n\">0</property></object><packing><property name=\"left_attach\">0</pro"
  "perty><property name=\"top_attach\">1</property></packing></child><chil"
  "d><object class=\"GtkLabel\" id=\"dpms-off-label\"><property name=\"vis"
  "ible\">True</property><property name=\"can_focus\">False</property><pro"
  "perty name=\"margin_left\">18</property><property name=\"label\" transl"
  "atable=\"yes\">Switch off after</property><property name=\"xalign\">0</"
  "property></object><packing><property name=\"left_attach\">0</property><"
  "property name=\"top_attach\">2</property></packing></child><child><obje"
  "ct class=\"GtkBox\"><property name=\"visible\">True</property><property"
  " name=\"can_focus\">False</property><property name=\"hexpand\">True</pr"
  "operty><property name=\"orientation\">vertical</property><child><object"
  " class=\"GtkScale\" id=\"dpms-off-on-battery\"><property name=\"visible"
  "\">True</property><property name=\"can_focus\">True</property><property"
  " name=\"hexpand\">True</property><property name=\"adjustment\">dpms-off"
  "-on-battery-adjustment</property><property name=\"round_digits\">0</pro"
  "perty><property name=\"digits\">0</property><property name=\"draw_value"
  "\">False</property><style><class name=\"xfce4-scale-label\"/></style></"
  "object><packing><property name=\"expand\">False</property><property nam"
  "e=\"fill\">True</property><property name=\"position\">0</property></pac"
  "king></child><child><object class=\"GtkLabel\" id=\"dpms-off-on-battery"
  "-label\"><property name=\"visible\">True</property><property name=\"sen"
  "sitive\">False</property><property name=\"can_focus\">False</property><"
  "property name=\"xalign\">0.5</property></object><packing><property name"
  "=\"expand\">False</property><property name=\"fill\">True</property><pro"
  "perty name=\"position\">1</property></packing></child></object><packing"
  "><property name=\"left_attach\">1</property><property name=\"top_attach"
  "\">2</property></packing></child><child><object class=\"GtkLabel\" id=\""
  "brightness-level-label\"><property name=\"visible\">True</property><pro"
  "perty name=\"can_focus\">False</property><property name=\"margin_left\""
  ">18</property><property name=\"label\" translatable=\"yes\">On inactivi"
  "ty reduce to</property><property name=\"xalign\">0</property></object><"
  "packing><property name=\"left_attach\">0</property><property name=\"top"
  "_attach\">4</property></packing></child><child><object class=\"GtkLabel"
  "\" id=\"brightness-inactivity-label\"><property name=\"visible\">True</"
  "property><property name=\"can_focus\">False</property><property name=\""
  "margin_left\">18</property><property name=\"label\" translatable=\"yes\""
  ">Reduce after</property><property name=\"xalign\">0</property></object>"
  "<packing><property name=\"left_attach\">0</property><property name=\"to"
  "p_attach\">5</property></packing></child><child><object class=\"GtkBox\""
  " id=\"brightness-level-vbox\"><property name=\"visible\">True</property"
  "><property name=\"can_focus\">False</property><property name=\"orientat"
  "ion\">vertical</property><child><object class=\"GtkScale\" id=\"brightn"
  "ess-level-on-battery\"><property name=\"visible\">True</property><prope"
  "rty name=\"can_focus\">True</property><property name=\"hexpand\">True</"
  "property><property name=\"adjustment\">brightness-level-on-battery-adju"
  "stment</property><property name=\"round_digits\">0</property><property "
  "name=\"digits\">0</property><property name=\"draw_value\">False</proper"
  "ty><style><class name=\"xfce4-scale-label\"/></style></object><packing>"
  "<property name=\"expand\">False</property><property name=\"fill\">True<"
  "/property><property name=\"position\">0</property></packing></child><ch"
  "ild><object class=\"GtkLabel\" id=\"brightness-level-on-battery-label\""
  "><property name=\"visible\">True</property><property name=\"sensitive\""
  ">False</property><property name=\"can_focus\">False</property><property"
  " name=\"xalign\">0.5</property></object><packing><property name=\"expan"
  "d\">False</property><property name=\"fill\">True</property><property na"
  "me=\"position\">1</property></packing></child></object><packing><proper"
  "ty name=\"left_attach\">1</property><property name=\"top_attach\">4</pr"
  "operty></packing></child><child><object class=\"GtkBox\" id=\"brightnes"
  "s-inactivity-vbox\"><property name=\"visible\">True</property><property"
  " name=\"can_focus\">False</property><property name=\"orientation\">vert"
  "ical</property><child><object class=\"GtkScale\" id=\"brightness-inacti"
  "vity-on-battery\"><property name=\"visible\">True</property><property n"
  "ame=\"can_focus\">True</property><property name=\"hexpand\">True</prope"
  "rty><property name=\"adjustment\">brightness-inactivity-on-battery-adju"
  "stment</property><property name=\"round_digits\">0</property><property "
  "name=\"digits\">0</property><property name=\"draw_value\">False</proper"
  "ty><style><class name=\"xfce4-scale-label\"/></style></object><packing>"
  "<property name=\"expand\">False</property><property name=\"fill\">True<"
  "/property><property name=\"position\">0</property></packing></child><ch"
  "ild><object class=\"GtkLabel\" id=\"brightness-inactivity-on-battery-la"
  "bel\"><property name=\"visible\">True</property><property name=\"sensit"
  "ive\">False</property><property name=\"can_focus\">False</property><pro"
  "perty name=\"xalign\">0.5</property></object><packing><property name=\""
  "expand\">False</property><property name=\"fill\">True</property><proper"
  "ty name=\"position\">1</property></packing></child></object><packing><p"
  "roperty name=\"left_attach\">1</property><property name=\"top_attach\">"
  "5</property></packing></child><child><object class=\"GtkLabel\" id=\"la"
  "bel4\"><property name=\"visible\">True</property><property name=\"can_f"
  "ocus\">False</property><property name=\"margin_top\">12</property><prop"
  "erty name=\"label\" translatable=\"yes\">&lt;b&gt;Brightness reduction&"
  "lt;/b&gt;</property><property name=\"use_markup\">True</property><prope"
  "rty name=\"xalign\">0</property></object><packing><property name=\"left"
  "_attach\">0</property><property name=\"top_attach\">3</property><proper"
  "ty name=\"width\">2</property></packing></child></object><packing><prop"
  "erty name=\"name\">page0</property><property name=\"title\" translatabl"
  "e=\"yes\">On battery</property></packing></child><child><object class=\""
  "GtkGrid\" id=\"display-pluggedin-grid\"><property name=\"visible\">True"
  "</property><property name=\"can_focus\">False</property><property name="
  "\"row_spacing\">6</property><property name=\"column_spacing\">12</prope"
  "rty><child><object class=\"GtkLabel\" id=\"dpms-sleep-label1\"><propert"
  "y name=\"visible\">True</property><property name=\"can_focus\">False</p"
  "roperty><property name=\"margin_left\">18</property><property name=\"la"
  "bel\" translatable=\"yes\">Put to sleep after</property><property name="
  "\"xalign\">0</property></object><packing><property name=\"left_attach\""
  ">0</property><property name=\"top_attach\">1</property></packing></chil"
  "d><child><object class=\"GtkLabel\" id=\"dpms-off-label1\"><property na"
  "me=\"visible\">True</property><property name=\"can_focus\">False</prope"
  "rty><property name=\"margin_left\">18</property><property name=\"label\""
  " translatable=\"yes\">Switch off after</property><property name=\"xalig"
  "n\">0</property></object><packing><property name=\"left_attach\">0</pro"
  "perty><property name=\"top_attach\">2</property></packing></child><chil"
  "d><object class=\"GtkLabel\" id=\"label6\"><property name=\"visible\">T"
  "rue</property><property name=\"can_focus\">False</property><property na"
  "me=\"margin_top\">12</property><property name=\"label\" translatable=\""
  "yes\">&lt;b&gt;Brightness reduction&lt;/b&gt;</property><property name="
  "\"use_markup\">True</property><property name=\"xalign\">0</property></o"
  "bject><packing><property name=\"left_attach\">0</property><property nam"
  "e=\"top_attach\">3</property><property name=\"width\">2</property></pac"
  "king></child><child><object class=\"GtkLabel\" id=\"brightness-level-la"
  "bel1\"><property name=\"visible\">True</property><property name=\"can_f"
  "ocus\">False</property><property name=\"margin_left\">18</property><pro"
  "perty name=\"margin_top\">6</property><property name=\"label\" translat"
  "able=\"yes\">On inactivity reduce to</property><property name=\"xalign\""
  ">0</property></object><packing><property name=\"left_attach\">0</proper"
  "ty><property name=\"top_attach\">4</property></packing></child><child><"
  "object class=\"GtkLabel\" id=\"brightness-inactivity-label1\"><property"
  " name=\"visible\">True</property><property name=\"can_focus\">False</pr"
  "operty><property name=\"margin_left\">18</property><property name=\"lab"
  "el\" translatable=\"yes\">Reduce after</property><property name=\"xalig"
  "n\">0</property></object><packing><property name=\"left_attach\">0</pro"
  "perty><property name=\"top_attach\">5</property></packing></child><chil"
  "d><object class=\"GtkBox\" id=\"dpms-sleep-box1\"><property name=\"visi"
  "ble\">True</property><property name=\"can_focus\">False</property><prop"
  "erty name=\"orientation\">vertical</property><child><object class=\"Gtk"
  "Scale\" id=\"dpms-sleep-on-ac\"><property name=\"visible\">True</proper"
  "ty><property name=\"can_focus\">True</property><property name=\"hexpand"
  "\">True</property><property name=\"adjustment\">dpms-sleep-on-ac-adjust"
  "ment</property><property name=\"round_digits\">0</property><property na"
  "me=\"digits\">0</property><property name=\"draw_value\">False</property"
  "><style><class name=\"xfce4-scale-label\"/></style></object><packing><p"
  "roperty name=\"expand\">False</property><property name=\"fill\">True</p"
  "roperty><property name=\"position\">0</property></packing></child><chil"
  "d><object class=\"GtkLabel\" id=\"dpms-sleep-on-ac-label\"><property na"
  "me=\"visible\">True</property><property name=\"sensitive\">False</prope"
  "rty><property name=\"can_focus\">False</property><property name=\"xalig"
  "n\">0.5</property></object><packing><property name=\"expand\">False</pr"
  "operty><property name=\"fill\">True</property><property name=\"position"
  "\">1</property></packing></child></object><packing><property name=\"lef"
  "t_attach\">1</property><property name=\"top_attach\">1</property></pack"
  "ing></child><child><object class=\"GtkBox\"><property name=\"visible\">"
  "True</property><property name=\"can_focus\">False</property><property n"
  "ame=\"orientation\">vertical</property><child><object class=\"GtkScale\""
  " id=\"dpms-off-on-ac\"><property name=\"visible\">True</property><prope"
  "rty name=\"can_focus\">True</property><property name=\"hexpand\">True</"
  "property><property name=\"adjustment\">dpms-off-on-ac-adjustment</prope"
  "rty><property name=\"round_digits\">0</property><property name=\"digits"
  "\">0</property><property name=\"draw_value\">False</property><style><cl"
  "ass name=\"xfce4-scale-label\"/></style></object><packing><property nam"
  "e=\"expand\">False</property><property name=\"fill\">True</property><pr"
  "operty name=\"position\">0</property></packing></child><child><object c"
  "lass=\"GtkLabel\" id=\"dpms-off-on-ac-label\"><property name=\"visible\""
  ">True</property><property name=\"sensitive\">False</property><property "
  "name=\"can_focus\">False</property><property name=\"xalign\">0.5</prope"
  "rty></object><packing><property name=\"expand\">False</property><proper"
  "ty name=\"fill\">True</property><property name=\"position\">1</property"
  "></packing></child></object><packing><property name=\"left_attach\">1</"
  "property><property name=\"top_attach\">2</property></packing></child><c"
  "hild><object class=\"GtkBox\" id=\"brightness-level-vbox1\"><property n"
  "ame=\"visible\">True</property><property name=\"can_focus\">False</prop"
  "erty><property name=\"margin_top\">6</property><property name=\"orienta"
  "tion\">vertical</property><child><object class=\"GtkScale\" id=\"bright"
  "ness-level-on-ac\"><property name=\"visible\">True</property><property "
  "name=\"can_focus\">True</property><property name=\"hexpand\">True</prop"
  "erty><property name=\"adjustment\">brightness-level-on-ac-adjustment</p"
  "roperty><property name=\"round_digits\">0</property><property name=\"di"
  "gits\">0</property><property name=\"draw_value\">False</property><style"
  "><class name=\"xfce4-scale-label\"/></style></object><packing><property"
  " name=\"expand\">False</property><property name=\"fill\">True</property"
  "><property name=\"position\">0</property></packing></child><child><obje"
  "ct class=\"GtkLabel\" id=\"brightness-level-on-ac-label\"><property nam"
  "e=\"visible\">True</property><property name=\"sensitive\">False</proper"
  "ty><property name=\"can_focus\">False</property><property name=\"xalign"
  "\">0.5</property></object><packing><property name=\"expand\">False</pro"
  "perty><property name=\"fill\">True</property><property name=\"position\""
  ">1</property></packing></child></object><packing><property name=\"left_"
  "attach\">1</property><property name=\"top_attach\">4</property></packin"
  "g></child><child><object class=\"GtkBox\" id=\"brightness-inactivity-vb"
  "ox1\"><property name=\"visible\">True</property><property name=\"can_fo"
  "cus\">False</property><property name=\"hexpand\">True</property><proper"
  "ty name=\"orientation\">vertical</property><child><object class=\"GtkSc"
  "ale\" id=\"brightness-inactivity-on-ac\"><property name=\"visible\">Tru"
  "e</property><property name=\"can_focus\">True</property><property name="
  "\"adjustment\">brightness-inactivity-on-ac-adjustment</property><proper"
  "ty name=\"round_digits\">0</property><property name=\"digits\">0</prope"
  "rty><property name=\"draw_value\">False</property><style><class name=\""
  "xfce4-scale-label\"/></style></object><packing><property name=\"expand\""
  ">False</property><property name=\"fill\">True</property><property name="
  "\"position\">0</property></packing></child><child><object class=\"GtkLa"
  "bel\" id=\"brightness-inactivity-on-ac-label\"><property name=\"visible"
  "\">True</property><property name=\"sensitive\">False</property><propert"
  "y name=\"can_focus\">False</property><property name=\"xalign\">0.5</pro"
  "perty></object><packing><property name=\"expand\">False</property><prop"
  "erty name=\"fill\">True</property><property name=\"position\">1</proper"
  "ty></packing></child></object><packing><property name=\"left_attach\">1"
  "</property><property name=\"top_attach\">5</property></packing></child>"
  "</object><packing><property name=\"name\">page1</property><property nam"
  "e=\"title\" translatable=\"yes\">Plugged in</property><property name=\""
  "position\">1</property></packing></child></object><packing><property na"
  "me=\"expand\">True</property><property name=\"fill\">True</property><pr"
  "operty name=\"position\">3</property></packing></child></object><packin"
  "g><property name=\"position\">2</property></packing></child><child type"
  "=\"tab\"><object class=\"GtkLabel\" id=\"display\"><property name=\"vis"
  "ible\">True</property><property name=\"can_focus\">False</property><pro"
  "perty name=\"label\" translatable=\"yes\">Display</property></object><p"
  "acking><property name=\"position\">2</property><property name=\"tab_fil"
  "l\">False</property></packing></child></object><packing><property name="
  "\"expand\">True</property><property name=\"fill\">True</property><prope"
  "rty name=\"position\">0</property></packing></child></object><packing><"
  "property name=\"expand\">True</property><property name=\"fill\">True</p"
  "roperty><property name=\"position\">1</property></packing></child></obj"
  "ect></child><action-widgets><action-widget response=\"-11\">help-button"
  "</action-widget><action-widget response=\"-2\">screensaver-button</acti"
  "on-widget><action-widget response=\"-7\">close-button</action-widget></"
  "action-widgets></object><object class=\"GtkSizeGroup\" id=\"sg-critical"
  "-power\"><widgets><widget name=\"critical-power-level-label\"/><widget "
  "name=\"critical-power-action-label\"/></widgets></object></interface>"
};

static const unsigned xfpm_settings_ui_length = 57716u;

